==> igloo_0_1_5.zip: igloo_0_1_5/igloo/language/1/barnraiser_01/arrays/arr_error.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//error
$lang['arr_error'][1] =							"Database error.";
$lang['arr_error'][2] = 						"You have not entered an email.";
$lang['arr_error'][3] = 						"This email address is not valid.";
$lang['arr_error'][4] = 						"This email address is already in use.";
$lang['arr_error'][5] = 						"You have not entered a firstname.";
$lang['arr_error'][6] = 						"You have not entered a surname.";
$lang['arr_error'][7] = 						"You have not entered a nickname.";
$lang['arr_error'][8] = 						"You have not specified a gender.";
$lang['arr_error'][10] = 						"You have not entered a place of residence (home town).";
$lang['arr_error'][11] = 						"You have not entered a title.";
$lang['arr_error'][12] = 						"You have not entered a body text.";
$lang['arr_error'][13] = 						"You have not entered a description.";
$lang['arr_error'][14] = 						"Your email addresses must be identical.";
$lang['arr_error'][15] = 						"Your password fields must be identical.";
$lang['arr_error'][16] = 						"Your password field is too short. The password must be over 5 characters long.";
$lang['arr_error'][17] = 						"This file needs to jpg,gif,png,txt or pdf format.";
$lang['arr_error'][18] = 						"The email could not be sent.";
$lang['arr_error'][19] = 						"The email and password that you have entered do not match our records. Please try again.";
$lang['arr_error'][20] = 						"You must enter both your email and your password";
$lang['arr_error'][21] = 						"You have not entered a synopsis.";
$lang['arr_error'][22] = 						"We could not match your email and date of birth";
$lang['arr_error'][23] =						"Mail error.";
$lang['arr_error'][24] =						"The email that you have used to log in appears to be incorrect.";
$lang['arr_error'][25] = 						"You have not entered a password.";
$lang['arr_error'][26] = 						"We cannot let you in yet. Please press the link in the email we have sent you. If that still does not work, then please email support@your-domain.org";
$lang['arr_error'][27] = 						"Your access code does not appear to be right. You can copy it from the email you received and paste it here.";
$lang['arr_error'][28] = 						"You have to at least select one language that you can read.";
$lang['arr_error'][29] = 						"You do not have enough allocated disk space for file upload.";
$lang['arr_error'][30] = 						"You have not entered a synopsis.";
$lang['arr_error'][31] = 						"The email was not send as you have invited them already.";
$lang['arr_error'][32] = 						"This person is already in your social network.";
$lang['arr_error'][33] = 						"You have not set your homepage.";
$lang['arr_error'][34] = 						"The date that you have entered appears to be incorrect. Please enter a date in the format mm-dd-yyyy for the month, day and year. An example would be [10-31-1967].";
$lang['arr_error'][35] = 						"The time that you have entered appears to be incorrect. Please enter a time in the format hh:mm. An example would be [16:34].";
$lang['arr_error'][36] = 						"Your captcha word does not work. Please try again.";
$lang['arr_error'][37] = 						"You have not entered a question.";
$lang['arr_error'][38] = 						"You have not entered a start date.";
$lang['arr_error'][39] = 						"You have not entered an end date.";
$lang['arr_error'][40] = 						"You allocation value is not a number.";
$lang['arr_error'][41] = 						"Please use 3 or more characters when performing a search.";
$lang['arr_error'][42] = 						"Sorry, the file you wish to upload is bigger than the disk space you have allocated to you.";
$lang['arr_error'][43] =						"The date of birth that you have used to register appears to be incorrect. You will need this should you loose your password, so please enter your correct date of birth.";
$lang['arr_error'][44] = 						"You have not entered a url.";
$lang['arr_error'][45] = 						"You have not entered a profile name.";
$lang['arr_error'][46] = 						"When updating a file you can only replace a file with a file with the same type - ie: you can only replace a jpg with a jpg.";
$lang['arr_error'][47] = 						"You need to check at least one checkbox to send a message.";
$lang['arr_error'][48] =						"Sorry, your chosen wiki page name has already been taken. Please choose another name.";
$lang['arr_error'][49] = 						"Congratulations on trying to invite yourself into your social network;)";
?>

==> igloo_0_1_6.zip: igloo_0_1_6/igloo/language/1/barnraiser_01/arrays/arr_error.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//error
$lang['arr_error'][1] =							"Database error.";
$lang['arr_error'][2] = 						"You have not entered an email.";
$lang['arr_error'][3] = 						"This email address is not valid.";
$lang['arr_error'][4] = 						"This email address is already in use.";
$lang['arr_error'][5] = 						"You have not entered a firstname.";
$lang['arr_error'][6] = 						"You have not entered a surname.";
$lang['arr_error'][7] = 						"You have not entered a nickname.";
$lang['arr_error'][8] = 						"You have not specified a gender.";
$lang['arr_error'][10] = 						"You have not entered a place of residence (home town).";
$lang['arr_error'][11] = 						"You have not entered a title.";
$lang['arr_error'][12] = 						"You have not entered a body text.";
$lang['arr_error'][13] = 						"You have not entered a description.";
$lang['arr_error'][14] = 						"Your email addresses must be identical.";
$lang['arr_error'][15] = 						"Your password fields must be identical.";
$lang['arr_error'][16] = 						"Your password field is too short. The password must be over 5 characters long.";
$lang['arr_error'][17] = 						"This file needs to jpg,gif,png,txt or pdf format.";
$lang['arr_error'][18] = 						"The email could not be sent.";
$lang['arr_error'][19] = 						"The email and password that you have entered do not match our records. Please try again.";
$lang['arr_error'][20] = 						"You must enter both your email and your password";
$lang['arr_error'][21] = 						"You have not entered a synopsis.";
$lang['arr_error'][22] = 						"We could not match your email and date of birth";
$lang['arr_error'][23] =						"Mail error.";
$lang['arr_error'][24] =						"The email that you have used to log in appears to be incorrect.";
$lang['arr_error'][25] = 						"You have not entered a password.";
$lang['arr_error'][26] = 						"We cannot let you in yet. Please press the link in the email we have sent you. If that still does not work, then please email support@your-domain.org";
$lang['arr_error'][27] = 						"Your access code does not appear to be right. You can copy it from the email you received and paste it here.";
$lang['arr_error'][28] = 						"You have to at least select one language that you can read.";
$lang['arr_error'][29] = 						"You do not have enough allocated disk space for file upload.";
$lang['arr_error'][30] = 						"You have not entered a synopsis.";
$lang['arr_error'][31] = 						"The email was not send as you have invited them already.";
$lang['arr_error'][32] = 						"This person is already in your social network.";
$lang['arr_error'][33] = 						"You have not set your homepage.";
$lang['arr_error'][34] = 						"The date that you have entered appears to be incorrect. Please enter a date in the format mm-dd-yyyy for the month, day and year. An example would be [10-31-1967].";
$lang['arr_error'][35] = 						"The time that you have entered appears to be incorrect. Please enter a time in the format hh:mm. An example would be [16:34].";
$lang['arr_error'][36] = 						"Your captcha word does not work. Please try again.";
$lang['arr_error'][37] = 						"You have not entered a question.";
$lang['arr_error'][38] = 						"You have not entered a start date.";
$lang['arr_error'][39] = 						"You have not entered an end date.";
$lang['arr_error'][40] = 						"Your allocation value is not a number.";
$lang['arr_error'][41] = 						"Please use 3 or more characters when performing a search.";
$lang['arr_error'][42] = 						"Sorry, the file you wish to upload is bigger than the disk space you have allocated to you.";
$lang['arr_error'][43] =						"The date of birth that you have used to register appears to be incorrect. You will need this should you loose your password, so please enter your correct date of birth.";
$lang['arr_error'][44] = 						"You have not entered a url.";
$lang['arr_error'][45] = 						"You have not entered a profile name.";
$lang['arr_error'][46] = 						"When updating a file you can only replace a file with a file with the same type - ie: you can only replace a jpg with a jpg.";
$lang['arr_error'][47] = 						"You need to check at least one checkbox to send a message.";
$lang['arr_error'][48] =						"Sorry, your chosen wiki page name has already been taken. Please choose another name.";
$lang['arr_error'][49] = 						"Congratulations on trying to invite yourself into your social network;)";
$lang['arr_error'][50] = 						"You have not entered a wiki page name.";
$lang['arr_error'][51] = 						"A wiki page name must be a combination of uppercase and lowercase characters (LikeThis) and must only contain a-z and 0-9 characters.";

?>
